;; Generated package description from flamegraph.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "flamegraph" "0.1.0.20260603.69" "Flame graphs for Emacs's native profiler and folded stacks files" '((emacs "30.1")) :commit "bdb6080cfcef15f77be6542065a53e344fb68910" :authors '(("Dmitry Gutov" . "dmitry@gutov.dev")) :maintainer '("Dmitry Gutov" . "dmitry@gutov.dev") :keywords '("lisp" "tools") :url "https://github.com/dgutov/emacs-flamegraph/")
